# Yuci Dictionary

version = 0.1.4

## Introduction

> A tiny CLI dictionary built by python, based on youdao-web dictionary and require an internet connection. 

​	Yuci Dictionary is a simple dictionary built in your command line. Without too many useless examples and ads, Yuci Dictionary can provide you clear interface and the amount of examples and definitions are just right for your daily life.

Features:

- :dash: Simple way to search on cmd.
- :smile: Aimed to your daily life.
- :hammer_and_wrench: ~~Relatively search, convert ＇wod＇ to ＇word＇ for example.~~(Will add in next update, hopefully)
- :hammer_and_wrench: ~~History Search~~(Will add in the future)

## Install

​	To install Yuci Dictionary, just type `pip install yuci-dictionary` in cmd, or you can download the resource file and type `python setup.py install` in the folder.

## Get Start

​	Just type `dict`to enter dictionary. When you see `yuci>`, you are ready to use the dictionary. type `search [word]` to search for a word or you can use`s [word]`as a shortcut for search method.

```
yuci> search hello
...
yuci> s hello
...
```

​	For more customized setting information, type `help [action]` to see the help file of the action.

```
yuci> help setting
...
yuci> help
...
```



## To-do list

- [x]  youdao support
- [x]  cmd support
- [x]  help file
- [ ]  expand search function
- [ ]  history search
- [ ]  offline library

## Project website

- PyPI: <https://pypi.org/project/Yuci-Dictionary/>
- Github: <https://github.com/Yucklys/yuci-dictionary>
